@@ -13,7 +13,6 @@
 # under the License.
 
 from oslo_log import log as logging
-import six
 
 from octavia.amphorae.drivers import driver_base
 from octavia.amphorae.drivers.keepalived.jinja import jinja_cfg
@@ -25,7 +24,7 @@ API_VERSION = constants.API_VERSION
 
 class KeepalivedAmphoraDriverMixin(driver_base.VRRPDriverMixin):
     def __init__(self):
-        super(KeepalivedAmphoraDriverMixin, self).__init__()
+        super().__init__()
 
         # The Mixed class must define a self.client object for the
         # AmphoraApiClient
@@ -51,9 +50,15 @@ class KeepalivedAmphoraDriverMixin(driver_base.VRRPDriverMixin):
 
         LOG.debug("Update amphora %s VRRP configuration.", amphora.id)
 
-        self._populate_amphora_api_version(amphora)
+        self._populate_amphora_api_version(amphora,
+                                           timeout_dict=timeout_dict)
         # Get the VIP subnet prefix for the amphora
-        vip_cidr = amphorae_network_config[amphora.id].vip_subnet.cidr
+        # For amphorav2 amphorae_network_config will be list of dicts
+        try:
+            vip_cidr = amphorae_network_config[amphora.id].vip_subnet.cidr
+        except AttributeError:
+            vip_cidr = amphorae_network_config[amphora.id][
+                constants.VIP_SUBNET][constants.CIDR]
 
         # Generate Keepalived configuration from loadbalancer object
         config = templater.build_keepalived_config(
@@ -68,7 +73,7 @@ class KeepalivedAmphoraDriverMixin(driver_base.VRRPDriverMixin):
         LOG.info("Stop loadbalancer %s amphora VRRP Service.",
                  loadbalancer.id)
 
-        for amp in six.moves.filter(
+        for amp in filter(
             lambda amp: amp.status == constants.AMPHORA_ALLOCATED,
                 loadbalancer.amphorae):
 
@@ -103,7 +108,7 @@ class KeepalivedAmphoraDriverMixin(driver_base.VRRPDriverMixin):
         LOG.info("Reload loadbalancer %s amphora VRRP Service.",
                  loadbalancer.id)
 
-        for amp in six.moves.filter(
+        for amp in filter(
             lambda amp: amp.status == constants.AMPHORA_ALLOCATED,
                 loadbalancer.amphorae):
 
