@@ -57,9 +57,14 @@ class AmphoraFlows(object):
             provides=constants.COMPUTE_ID))
         create_amphora_flow.add(database_tasks.MarkAmphoraBootingInDB(
             requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
-        create_amphora_flow.add(compute_tasks.ComputeActiveWait(
-            requires=(constants.COMPUTE_ID, constants.AMPHORA_ID),
-            provides=constants.COMPUTE_OBJ))
+        retry_subflow = linear_flow.Flow(
+            constants.COMPUTE_CREATE_RETRY_SUBFLOW,
+            retry=compute_tasks.ComputeRetry())
+        retry_subflow.add(
+            compute_tasks.ComputeWait(
+                requires=(constants.COMPUTE_ID, constants.AMPHORA_ID),
+                provides=constants.COMPUTE_OBJ))
+        create_amphora_flow.add(retry_subflow)
         create_amphora_flow.add(database_tasks.UpdateAmphoraInfo(
             requires=(constants.AMPHORA_ID, constants.COMPUTE_OBJ),
             provides=constants.AMPHORA))
@@ -113,11 +118,7 @@ class AmphoraFlows(object):
         create_amp_for_lb_subflow.add(database_tasks.MarkAmphoraBootingInDB(
             name=sf_name + '-' + constants.MARK_AMPHORA_BOOTING_INDB,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_ID)))
-        create_amp_for_lb_subflow.add(compute_tasks.ComputeActiveWait(
-            name=sf_name + '-' + constants.COMPUTE_WAIT,
-            requires=(constants.COMPUTE_ID, constants.AMPHORA_ID,
-                      constants.AVAILABILITY_ZONE),
-            provides=constants.COMPUTE_OBJ))
+        create_amp_for_lb_subflow.add(self._retry_compute_wait_flow(sf_name))
         create_amp_for_lb_subflow.add(database_tasks.UpdateAmphoraInfo(
             name=sf_name + '-' + constants.UPDATE_AMPHORA_INFO,
             requires=(constants.AMPHORA_ID, constants.COMPUTE_OBJ),
@@ -146,6 +147,18 @@ class AmphoraFlows(object):
 
         return create_amp_for_lb_subflow
 
+    def _retry_compute_wait_flow(self, sf_name):
+        retry_task = sf_name + '-' + constants.COMPUTE_WAIT
+        retry_subflow = linear_flow.Flow(
+            sf_name + '-' + constants.COMPUTE_CREATE_RETRY_SUBFLOW,
+            retry=compute_tasks.ComputeRetry())
+        retry_subflow.add(
+            compute_tasks.ComputeWait(
+                name=retry_task,
+                requires=(constants.COMPUTE_ID, constants.AMPHORA_ID),
+                provides=constants.COMPUTE_OBJ))
+        return retry_subflow
+
     def _retry_flow(self, sf_name):
         retry_task = sf_name + '-' + constants.AMP_COMPUTE_CONNECTIVITY_WAIT
         retry_subflow = linear_flow.Flow(
@@ -403,18 +416,17 @@ class AmphoraFlows(object):
         amp_for_failover_flow.add(network_tasks.CalculateAmphoraDelta(
             name=prefix + '-' + constants.CALCULATE_AMPHORA_DELTA,
             requires=(constants.LOADBALANCER, constants.AMPHORA,
-                      constants.AVAILABILITY_ZONE, constants.VRRP_PORT),
-            rebind={constants.VRRP_PORT: constants.BASE_PORT},
+                      constants.AVAILABILITY_ZONE),
             provides=constants.DELTA))
 
         amp_for_failover_flow.add(network_tasks.HandleNetworkDelta(
             name=prefix + '-' + constants.HANDLE_NETWORK_DELTA,
             requires=(constants.AMPHORA, constants.DELTA),
-            provides=constants.ADDED_PORTS))
+            provides=constants.UPDATED_PORTS))
 
         amp_for_failover_flow.add(amphora_driver_tasks.AmphoraePostNetworkPlug(
             name=prefix + '-' + constants.AMPHORAE_POST_NETWORK_PLUG,
-            requires=(constants.LOADBALANCER, constants.ADDED_PORTS)))
+            requires=(constants.LOADBALANCER, constants.UPDATED_PORTS)))
 
         return amp_for_failover_flow
 
