@@ -87,12 +87,18 @@ class LoadBalancerFlows(object):
 
         post_amp_prefix = constants.POST_LB_AMP_ASSOCIATION_SUBFLOW
         lb_create_flow.add(
-            self.get_post_lb_amp_association_flow(
-                post_amp_prefix, topology, mark_active=(not listeners)))
+            self.get_post_lb_amp_association_flow(post_amp_prefix, topology))
 
         if listeners:
             lb_create_flow.add(*self._create_listeners_flow())
 
+        lb_create_flow.add(
+            database_tasks.MarkLBActiveInDB(
+                mark_subobjects=True,
+                requires=constants.LOADBALANCER
+            )
+        )
+
         return lb_create_flow
 
     def _create_single_topology(self):
@@ -196,27 +202,27 @@ class LoadBalancerFlows(object):
         )
         flows.append(
             network_tasks.HandleNetworkDeltas(
-                requires=constants.DELTAS, provides=constants.ADDED_PORTS
+                requires=constants.DELTAS, provides=constants.UPDATED_PORTS
+            )
+        )
+        flows.append(
+            network_tasks.GetAmphoraeNetworkConfigs(
+                requires=constants.LOADBALANCER_ID,
+                provides=constants.AMPHORAE_NETWORK_CONFIG
             )
         )
         flows.append(
             amphora_driver_tasks.AmphoraePostNetworkPlug(
-                requires=(constants.LOADBALANCER, constants.ADDED_PORTS)
+                requires=(constants.LOADBALANCER, constants.UPDATED_PORTS,
+                          constants.AMPHORAE_NETWORK_CONFIG)
             )
         )
         flows.append(
             self.listener_flows.get_create_all_listeners_flow()
         )
-        flows.append(
-            database_tasks.MarkLBActiveInDB(
-                mark_subobjects=True,
-                requires=constants.LOADBALANCER
-            )
-        )
         return flows
 
-    def get_post_lb_amp_association_flow(self, prefix, topology,
-                                         mark_active=True):
+    def get_post_lb_amp_association_flow(self, prefix, topology):
         """Reload the loadbalancer and create networking subflows for
 
         created/allocated amphorae.
@@ -239,10 +245,6 @@ class LoadBalancerFlows(object):
 
         post_create_LB_flow.add(database_tasks.UpdateLoadbalancerInDB(
             requires=[constants.LOADBALANCER, constants.UPDATE_DICT]))
-        if mark_active:
-            post_create_LB_flow.add(database_tasks.MarkLBActiveInDB(
-                name=sf_name + '-' + constants.MARK_LB_ACTIVE_INDB,
-                requires=constants.LOADBALANCER))
         return post_create_LB_flow
 
     def _get_delete_listeners_flow(self, listeners):
