@@ -259,7 +259,7 @@ class AmphoraFinalize(BaseAmphoraTask):
 class AmphoraPostNetworkPlug(BaseAmphoraTask):
     """Task to notify the amphora post network plug."""
 
-    def execute(self, amphora, ports):
+    def execute(self, amphora, ports, amphora_network_config):
         """Execute post_network_plug routine."""
         db_amp = self.amphora_repo.get(db_apis.get_session(),
                                        id=amphora[constants.ID])
@@ -279,8 +279,9 @@ class AmphoraPostNetworkPlug(BaseAmphoraTask):
                 fixed_ips.append(data_models.FixedIP(
                     subnet=data_models.Subnet(**subnet_arg), **ip))
             self.amphora_driver.post_network_plug(
-                db_amp, data_models.Port(network=net, fixed_ips=fixed_ips,
-                                         **port))
+                db_amp,
+                data_models.Port(network=net, fixed_ips=fixed_ips, **port),
+                amphora_network_config)
 
             LOG.debug("post_network_plug called on compute instance "
                       "%(compute_id)s for port %(port_id)s",
@@ -298,17 +299,18 @@ class AmphoraPostNetworkPlug(BaseAmphoraTask):
 class AmphoraePostNetworkPlug(BaseAmphoraTask):
     """Task to notify the amphorae post network plug."""
 
-    def execute(self, loadbalancer, added_ports):
+    def execute(self, loadbalancer, updated_ports, amphorae_network_config):
         """Execute post_network_plug routine."""
         amp_post_plug = AmphoraPostNetworkPlug()
         db_lb = self.loadbalancer_repo.get(
             db_apis.get_session(), id=loadbalancer[constants.LOADBALANCER_ID])
         for amphora in db_lb.amphorae:
-            if amphora.id in added_ports:
+            if amphora.id in updated_ports:
                 amp_post_plug.execute(amphora.to_dict(),
-                                      added_ports[amphora.id])
+                                      updated_ports[amphora.id],
+                                      amphorae_network_config[amphora.id])
 
-    def revert(self, result, loadbalancer, added_ports, *args, **kwargs):
+    def revert(self, result, loadbalancer, updated_ports, *args, **kwargs):
         """Handle a failed post network plug."""
         if isinstance(result, failure.Failure):
             return
