@@ -15,6 +15,7 @@
 
 import copy
 import os
+from unittest import mock
 
 from octavia_lib.common import constants as lib_consts
 from oslo_config import cfg
@@ -65,7 +66,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -120,7 +120,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -171,7 +170,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -227,7 +225,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -281,7 +278,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -335,7 +331,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -387,7 +382,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -423,7 +417,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -499,7 +492,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -536,7 +528,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -572,7 +563,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -601,7 +591,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -642,7 +631,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -679,7 +667,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode tcp\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option ssl-hello-chk\n"
               "    fullconn {maxconn}\n"
@@ -747,7 +734,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option external-check\n"
               "    external-check command /var/lib/octavia/ping-wrapper.sh\n"
@@ -771,6 +757,36 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
             backend=be, global_opts=go), rendered_obj)
 
+    def test_render_template_ping_monitor_http_insecure_fork(self):
+        be = ("backend sample_pool_id_1:sample_listener_id_1\n"
+              "    mode http\n"
+              "    balance roundrobin\n"
+              "    cookie SRV insert indirect nocache\n"
+              "    timeout check 31s\n"
+              "    option external-check\n"
+              "    external-check command /var/lib/octavia/ping-wrapper.sh\n"
+              "    fullconn {maxconn}\n"
+              "    option allbackups\n"
+              "    timeout connect 5000\n"
+              "    timeout server 50000\n"
+              "    server sample_member_id_1 10.0.0.99:82 "
+              "weight 13 check inter 30s fall 3 rise 2 "
+              "cookie sample_member_id_1\n"
+              "    server sample_member_id_2 10.0.0.98:82 "
+              "weight 13 check inter 30s fall 3 rise 2 "
+              "cookie sample_member_id_2\n\n").format(
+            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+        go = (f"    maxconn {constants.HAPROXY_DEFAULT_MAXCONN}\n"
+              "    external-check\n    insecure-fork-wanted\n\n")
+        rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
+            sample_configs_combined.sample_amphora_tuple(),
+            [sample_configs_combined.sample_listener_tuple(
+                proto='HTTP', monitor_proto='PING')],
+            feature_compatibility={
+                "requires_insecure_fork": True})
+        self.assertEqual(sample_configs_combined.sample_base_expected_config(
+            backend=be, global_opts=go), rendered_obj)
+
     def test_render_template_no_monitor_https(self):
         fe = ("frontend sample_listener_id_1\n"
               "    maxconn {maxconn}\n"
@@ -808,7 +824,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.1\\r\\nHost:\\ "
               "testlab.com\n"
@@ -886,7 +901,6 @@ class TestHaproxyCfg(base.TestCase):
               "    balance roundrobin\n"
               "    stick-table type ip size 10k\n"
               "    stick on src\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -914,7 +928,6 @@ class TestHaproxyCfg(base.TestCase):
               "    stick-table type string len 64 size 10k\n"
               "    stick store-response res.cook(JSESSIONID)\n"
               "    stick match req.cook(JSESSIONID)\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1038,7 +1051,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1055,7 +1067,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /healthmon.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1077,7 +1088,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1106,7 +1116,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1137,7 +1146,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    fullconn {maxconn}\n"
               "    option allbackups\n"
@@ -1165,7 +1173,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1206,7 +1213,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1246,7 +1252,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1287,7 +1292,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1325,7 +1329,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1359,7 +1362,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1390,7 +1392,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1602,7 +1603,7 @@ class TestHaproxyCfg(base.TestCase):
                 defaults=defaults, logging="\n"),
             rendered_obj)
 
-    def test_http_reuse(self):
+    def test_haproxy_cfg_1_8_vs_1_5(self):
         j_cfg = jinja_cfg.JinjaTemplater(
             base_amp_path='/var/lib/octavia',
             base_crt_dir='/var/lib/octavia/certs')
@@ -1610,7 +1611,12 @@ class TestHaproxyCfg(base.TestCase):
         sample_amphora = sample_configs_combined.sample_amphora_tuple()
         sample_proxy_listener = sample_configs_combined.sample_listener_tuple(
             be_proto='PROXY')
-        # With http-reuse
+        # With http-reuse and server-state-file
+        go = (
+            "    server-state-file /var/lib/octavia/sample_loadbalancer_id_1/"
+            "servers-state\n"
+            "    maxconn {maxconn}\n\n").format(
+            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
         be = ("backend {pool_id}:{listener_id}\n"
               "    mode http\n"
               "    http-reuse safe\n"
@@ -1637,15 +1643,15 @@ class TestHaproxyCfg(base.TestCase):
             tls_certs=None,
             haproxy_versions=("1", "8", "1"))
         self.assertEqual(
-            sample_configs_combined.sample_base_expected_config(backend=be),
+            sample_configs_combined.sample_base_expected_config(
+                global_opts=go, backend=be),
             rendered_obj)
 
-        # Without http-reuse
+        # Without http-reuse and server-state-file
         be = ("backend {pool_id}:{listener_id}\n"
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    fullconn {maxconn}\n"
               "    option allbackups\n"
@@ -1719,7 +1725,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /index.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1735,7 +1740,6 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
-              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option httpchk GET /healthmon.html HTTP/1.0\\r\\n\n"
               "    http-check expect rstatus 418\n"
@@ -1758,3 +1762,111 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_combined.sample_base_expected_config(
                 frontend=fe, backend=be),
             rendered_obj)
+
+    @mock.patch("octavia.common.jinja.haproxy.combined_listeners.jinja_cfg."
+                "JinjaTemplater.render_loadbalancer_obj")
+    def test_build_config(self, mock_render_loadbalancer_obj):
+        mock_amp = mock.Mock()
+        mock_listeners = mock.Mock()
+        mock_tls_certs = mock.Mock()
+        mock_socket_path = mock.Mock()
+
+        j_cfg = jinja_cfg.JinjaTemplater()
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("0", "7", "0"),
+                           socket_path=mock_socket_path)
+
+        expected_fc = {}
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("1", "6", "0"),
+                           socket_path=mock_socket_path)
+
+        expected_fc = {
+            constants.HTTP_REUSE: True,
+            constants.SERVER_STATE_FILE: True
+
+        }
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("1", "9", "0"),
+                           socket_path=mock_socket_path)
+
+        expected_fc = {
+            constants.HTTP_REUSE: True,
+            constants.SERVER_STATE_FILE: True,
+            constants.POOL_ALPN: True
+        }
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("2", "1", "1"),
+                           socket_path=mock_socket_path)
+
+        expected_fc = {
+            constants.HTTP_REUSE: True,
+            constants.SERVER_STATE_FILE: True,
+            constants.POOL_ALPN: True,
+            lib_consts.PROTOCOL_PROMETHEUS: True
+        }
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("2", "2", "1"),
+                           socket_path=mock_socket_path)
+
+        expected_fc = {
+            constants.HTTP_REUSE: True,
+            constants.SERVER_STATE_FILE: True,
+            constants.POOL_ALPN: True,
+            lib_consts.PROTOCOL_PROMETHEUS: True,
+            constants.INSECURE_FORK: True
+        }
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("2", "4", "0"),
+                           socket_path=mock_socket_path)
+
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
+
+        mock_render_loadbalancer_obj.reset_mock()
+
+        j_cfg.build_config(mock_amp, mock_listeners, mock_tls_certs,
+                           haproxy_versions=("3", "1", "0"),
+                           socket_path=mock_socket_path)
+
+        mock_render_loadbalancer_obj.assert_called_once_with(
+            mock_amp, mock_listeners, tls_certs=mock_tls_certs,
+            socket_path=mock_socket_path,
+            feature_compatibility=expected_fc)
